import argparse
import sys
import logging
import traceback
import os
from multiprocessing import Queue, Process, cpu_count

logging.basicConfig()
logger = logging.getLogger()
logger.setLevel(logging.INFO)
handler = logging.StreamHandler(sys.stdout)
handler.setLevel(logging.INFO)

def mainFunction(args):
    print(hello)

def main():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers()

    # use bpga2 section
    files = subparsers.add_parser("main", help="main function for metapan")
    files.add_argument('-i', metavar='InputFileDirectory',dest='InputFileDirectory', required=True,
                       help='Enter path to input directory containing fasta file')
    files.add_argument('-o', metavar='OutputFile',dest='OutputFile', required=True,
                       help='Enter name for input File')
    files.add_argument('-m', metavar='Metadatafile',dest='Metadatafile', required=True,
                       help='Enter name for input File')
    files.add_argument('-t', metavar='threads',dest='threads', default=cpu_count(),
                       help='Enter number of threads')
    files.set_defaults(func=mainFunction)

       # Get all arguments
    args = parser.parse_args()
    try:
        args.func(args)
    except AttributeError:
        parser.print_help()
        parser.exit()

    pass
if __name__ == '__main__':
	main()



from setuptools import setup, find_packages 
  
# with open('requirements.txt') as f: 
#     requirements = f.readlines() 
  
long_description = 'later' 
  
setup( 
        name ='metapan', 
        version ='0.0.2', 
        author ='Anupam Gautam', 
        author_email ='gautamanupam07@gmail.com', 
        url ='https://github.com/AnupamGautam/metapan.git', 
        description ='Start', 
        long_description = long_description, 
        long_description_content_type ="text/markdown", 
        license ='GPL-3.0', 
        packages = find_packages(), 
        entry_points ={ 
            'console_scripts': [ 
                'metapan = metapan.metapan:main'
            ] 
        }, 
        classifiers =( 
            "Programming Language :: Python :: 3.8", 
            "License :: OSI Approved :: MIT License", 
            "Operating System :: OS Independent", 
        ), 
        keywords ='pangenome on metagenome', 
        zip_safe = True
) 
